unaconfig library

A library for searching for configuration files.

Classes

ConfigMatchDetails
ConfigParser
A parser for searching for a configuration. The pattern is used to match against the file name. The getConfig function is used to parse the configuration file contents. The fs is the file system to use to read the configuration file (defaults to the local file system).
Unaconfig
This class is used to search for configuration files in a directory or directories.